@@ -29,8 +29,9 @@ private:
 
 static map <string,string> params;
 
-static void ReadConfig( string file );
+static bool ReadConfig( string file );
 static void ShowConfig( string cfgfile );
+static bool TestConfig();
 static void Usage();
 static void SetDefaults();
 
