@@ -50,16 +50,24 @@ int totalscanners, top_fd, answers;
 vector<string> ErrorMsg;
 vector<string> VirusMsg;
 
+vector<string> IgnoredViruses;
+
 vector<scanner_st> Scanner;
 vector<GenericScanner*> VirusScanner;
 
 unsigned long TempFileLength;
 
+bool DeadScanner;
+bool CompleteTempFile;
+string LastRequestURL;
+
+bool IgnoredVirus( string VirusName );
+
 public:
 
 bool InitScanners();
 bool CreateScanners( SocketHandler &ProxyServerT );
-bool ReloadDatabases();
+int ReloadDatabases();
 bool RestartScanners();
 void ExitScanners();
 #ifndef NOMAND
@@ -68,6 +76,9 @@ bool HasAnswer();
 int GetAnswer();
 string GetAnswerMessage();
 
+void LastURL( string URL );
+void HaveCompleteFile();
+
 bool InitTempFile();
 bool UnlockTempFile();
 bool DeleteTempFile();
@@ -75,9 +86,7 @@ bool ReinitTempFile();
 bool SetTempFileSize( long long ContentLengthT );
 bool TruncateTempFile( long long ContentLengthT );
 bool ExpandTempFile( string &dataT, bool unlockT );
-#ifndef NOMAND
 bool ExpandTempFileRange( string &dataT, long long offset );
-#endif
 
 ScannerHandler();
 ~ScannerHandler();
