@@ -26,18 +26,26 @@ private:
 
 string ScannerCmd;
 
-SocketHandler ArcavirSocket;
+SocketHandler Scanner;
 time_t LastError;
 
 string ScannerAnswer;
 char Ready[2];
 
+bool Connected;
+int Version;
+
+string ScanV2007( const char *FileName );
+string ScanV2008( const char *FileName );
+bool ConnectScanner();
+
 public:
 
 bool InitDatabase();
 int ReloadDatabase();
 void FreeDatabase();
 string Scan( const char *FileName );
+void CloseSocket();
 
 ArcavirScanner();
 ~ArcavirScanner();
