@@ -37,7 +37,7 @@ string ScannerCmd;
 public:
 
 bool InitDatabase();
-bool ReloadDatabase();
+int ReloadDatabase();
 void FreeDatabase();
 string Scan( const char *FileName );
 
